/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/


#include <windows.h>
#include "stdafx.h"
#include "fsioctl.h"

#ifndef _MOXA_V2401_CE_
#define	_MOXA_V2401_CE_	1


/*******************************  IMPORTANT NOTICE *********************************/
/*  You have to copy mxdev.dll to \windows directory                               */
/*  The mxdev.dll is in the path "C:\Windows CE Tools\wce600\W406-CESDKV1.0\Lib\ARMV4i"  */


/* extra DeviceIOControl Code for Moxa MU860 UART */
#define MOXA					0x400
#define MOXA_SET_OP_MODE		(MOXA + 66)
#define MOXA_GET_OP_MODE		(MOXA + 67)

#define RS232_MODE				0	
#define RS485_2WIRE_MODE		1
#define RS422_MODE				2
#define RS485_4WIRE_MODE		3
#define OP_MODE_MASK			3


//////////////////////// begin section watchdog ///////////////////
/*	DeviceIoControl() code for initializing the watchdog timer
	Inputs:
		<lpInBuffer>	 point of a DWORD value. Initialize the watchdog timer in Milli-seconds.
		<nInBufferSize>  the length of lpInBuffer
	Outpus:
		<lpOutBuffer>    None
		<nOutBufferSize> the length of lpOutBuffer
	Returns:
		TRUE indicates the success, FALSE inidicates the fail.
*/
#define IOCTL_START_WDG							CTL_CODE( 0, 164, 0, 0)

/*	DeviceIoControl() code for refreshing the watchdog timer
	Inputs:
		<lpInBuffer>	 NULL
		<nInBufferSize>  the length of lpInBuffer
	Outpus:
		<lpOutBuffer>    NULL
		<nOutBufferSize> the length of lpOutBuffer
	Returns:
		TRUE indicates the success, FALSE inidicates the fail.
*/
#define IOCTL_STOP_WDG							CTL_CODE( 0, 165, 0, 0)

/*	DeviceIoControl() code for stopping the watchdog timer
	Inputs:
		<lpInBuffer>	 NULL
		<nInBufferSize>  the length of lpInBuffer
	Outpus:
		<lpOutBuffer>    NULL
		<nOutBufferSize> the length of lpOutBuffer
	Returns:
		TRUE indicates the success, FALSE inidicates the fail.
*/
#define IOCTL_REFRESH_WDG						CTL_CODE( 0, 166, 0, 0)

/*	initialize the watchdog timer
	Inputs:
		<dwRefreshPeriod>	 A DWORD value in Milli-seconds.
	Outpus:
		None
	Returns:
		the HANDLE of watchdog.
*/
HANDLE watchdog_init(DWORD dwRefreshPeriod);

/*	refresh the watchdog timer
	Inputs:
		<hWdg>	 watchdog HANDLE.
	Outpus:
		None
	Returns:
		TRUE indicates the success, FALSE inidicates the fail..
*/
BOOL watchdog_refresh(HANDLE hWdg);

/*	stop the watchdog timer
	Inputs:
		<hWdg>	 	watchdog HANDLE.
	Outpus:
		None
	Returns:
		TRUE indicates the success, FALSE inidicates the fail.
*/
BOOL watchdog_release(HANDLE hWdg);
///////////////////////// end section watchdog ////////////////////

/////////////////////////begin section uartmode ///////////////////

/*	change the uart mode
	Inputs:
		<port>	the port number. 1: COM1, 2:COM2, ...
		<mode>  0: RS232, 1: RS485-2W, 2: RS422, 3:RS485-4W
	Outpus:
		None
	Returns:
		TRUE indicates the success, FALSE inidicates the fail.
*/
BOOL uart_setmode(int port, int mode);

/*	get the uart mode
	Inputs:
		<port>	the port number. 1: COM1, 2:COM2, ...
	Outpus:
		None
	Returns:
		0: RS232, 1: RS485-2W, 2: RS422, 3:RS485-4W, otherwise the function fails.
*/
DWORD uart_getmode(int port);

///////////////////////// end section uartmode ///////////////////////

//////////////////////// begin section DIO ///////////////////

typedef struct _DIO {
	int	port;
	int	data;
} DIO_t, *PDIO_t;


/*	DeviceIoControl() code for set the DOUT value */
#define IOCTL_SET_DOUT             CTL_CODE( 0, 51, 0, 0)
/*	DeviceIoControl() code for get the DOUT value */
#define IOCTL_GET_DOUT             CTL_CODE( 0, 52, 0, 0)
/*	DeviceIoControl() code for get the DIN value */
#define IOCTL_GET_DIN			   CTL_CODE( 0, 53, 0, 0)


/*	initialize the DIO device
	Inputs:
		None
	Outpus:
		None
	Returns:
		the HANDLE of DIO.
*/
HANDLE mxdio_open(void);

/*	close the DIO device
	Inputs:
		<handle_dio>	the HANDLE of DIO.
	Outpus:
		None
	Returns:
		None.
*/
void mxdio_close(HANDLE handle_dio);

/*	set DOUT value
	Inputs:
		<handle_dio>  the HANDLE of DIO.
		<port>	      the port number. from 0 to 3
		<data>        1:High, 0:Low
	Outpus:
		None
	Returns:
		0 indicates success, otherwise the function fails.
*/
int mxdio_set_dout(HANDLE handle_dio, unsigned int port, unsigned int data);

/*	get DIN value
	Inputs:
		<handle_dio>  the HANDLE of DIO.
		<port>	      the port number. from 0 to 3
	Outpus:
		None
	Returns:
		1:High, 0:Low.
*/
int mxdio_get_din(HANDLE handle_dio, unsigned int port);

/*	get DOUT value
	Inputs:
		<handle_dio>  the HANDLE of DIO.
		<port>	      the port number. from 0 to 3
	Outpus:
		None
	Returns:
		1:High, 0:Low.
*/
int mxdio_get_dout(HANDLE handle_dio, unsigned int port);

///////////////////////// end section DIO////////////////////


//////////////////////// begin section BIOS ///////////////////

/*  BIOS Error Bits */
#define BIOS_BATTERY_FAILURE			0x80
#define BIOS_CMOS_CHECKSUM				0x40
#define BIOS_EQUIPMENT_MISSING			0x20
#define BIOS_MEMORY_SIZE_CHANGED		0x10
#define BIOS_FIXED_DISK_CONTROLLER		0x8
#define BIOS_DISPLAY_SWITCH_DISMATCH	0x4
#define BIOS_KEYBOARD_ERROR				0x2

/* extra DeviceIOControl Code for BIOS Info */
#define MOXA_READ_LVDS_SETTINGS	(MOXA + 68)
#define MOXA_READ_BIOS_STATUS	(MOXA + 69)

/*	Get BIOS Status
	Inputs:
		None
	Outpus:
		None
	Returns:
		the status value in BYTE.
*/
BYTE bios_get_status();

///////////////////////// end section DIO////////////////////

#endif //_MOXA_W406_CE_
